@@ -5,8 +5,8 @@ import (
 	"io"
 	"net/http"
 
-	"github.com/cloudskiff/driftctl/pkg/iac/config"
 	"github.com/pkg/errors"
+	"github.com/snyk/driftctl/pkg/iac/config"
 )
 
 var supportedBackends = []string{
@@ -15,6 +15,7 @@ var supportedBackends = []string{
 	BackendKeyHTTP,
 	BackendKeyHTTPS,
 	BackendKeyTFCloud,
+	BackendKeyGS,
 }
 
 type Backend io.ReadCloser
@@ -52,7 +53,9 @@ func GetBackend(config config.SupplierConfig, opts *Options) (Backend, error) {
 	case BackendKeyHTTPS:
 		return NewHTTPReader(&http.Client{}, fmt.Sprintf("%s://%s", config.Backend, config.Path), opts)
 	case BackendKeyTFCloud:
-		return NewTFCloudReader(&http.Client{}, config.Path, opts)
+		return NewTFCloudReader(config.Path, opts), nil
+	case BackendKeyGS:
+		return NewGSReader(config.Path)
 	default:
 		return nil, errors.Errorf("Unsupported backend '%s'", backend)
 	}
