@@ -7,12 +7,12 @@ import (
 	"runtime"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/analyser"
-	"github.com/cloudskiff/driftctl/pkg/memstore"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/version"
-	"github.com/cloudskiff/driftctl/test/mocks"
 	"github.com/jarcoal/httpmock"
+	"github.com/snyk/driftctl/pkg/analyser"
+	"github.com/snyk/driftctl/pkg/memstore"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/version"
+	"github.com/snyk/driftctl/test/mocks"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -104,7 +104,7 @@ func TestSendTelemetry(t *testing.T) {
 			if tt.expectedBody != nil {
 				httpmock.RegisterResponder(
 					"POST",
-					"https://2lvzgmrf2e.execute-api.eu-west-3.amazonaws.com/telemetry",
+					"https://telemetry.driftctl.com/telemetry",
 					func(req *http.Request) (*http.Response, error) {
 
 						requestTelemetry := &telemetry{}
@@ -140,7 +140,7 @@ func TestTelemetryNotSend(t *testing.T) {
 
 	httpmock.RegisterResponder(
 		"POST",
-		"https://2lvzgmrf2e.execute-api.eu-west-3.amazonaws.com/telemetry",
+		"https://telemetry.driftctl.com/telemetry",
 		httpmock.NewErrorResponder(nil),
 	)
 	tl := NewTelemetry(mocks.MockBuild{UsageReporting: false})
