@@ -1,7 +1,7 @@
 package terraform
 
 import (
-	"github.com/cloudskiff/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource"
 )
 
 type TerraformResourceFactory struct {
